#! /bin/bash

cat <<INTRO
*
* This script moves any existing /private/etc/hosts file
* to /private/etc/hosts-old and replaces it with a clean copy.
* 

This script must be run as from an Administrator account.
Enter the password for your macOS user account and press Enter.
NOTE: Your password will not be displayed as you type.

INTRO

## Verify user has macOS administrator credentials to continue
## An admin account must have a valid (non-blank) password for our script to work
# call sudo to get admin/root authentication
sudo whoami > /dev/null 2>&1

# if user has a mac admin password then continue
if [ $? = 0 ]; then
	echo ""
	echo "This is an Administrator account; proceeding with uninstallation."
else
	# else exit with error msg
	echo ""
	echo "This is not an Administrator account, or you did not enter the correct password."
	echo "Exiting."
	exit 1
fi

# Rename the /private/etc/hosts file if it exists

if [ -e /private/etc/hosts ]
then
    echo "Moving /private/etc/hosts file to /private/etc/hosts-old"
    sudo mv /private/etc/hosts /private/etc/hosts-old
else
    echo "NOTE: Can't find /private/etc/hosts file, skipping"
fi

# Write a new hosts file and move it to /private/etc/hosts

echo "Writing a new hosts file..."
cat <<HOSTS > hosts
##
# Host Database
#
# localhost is used to configure the loopback interface
# when the system is booting.  Do not change this entry.
##
127.0.0.1	localhost
255.255.255.255	broadcasthost
::1             localhost
HOSTS

echo "Moving new hosts file to /private/etc/hosts..."
sudo mv hosts /private/etc/

# Set the ownership and permissions of the new hosts file

echo "Setting ownership and permissions..."
sudo chown root:wheel /private/etc/hosts
sudo chmod 644 /private/etc/hosts

# Restart the mDNSResponder process

echo "Restarting mDNSResponder..."
sudo killall -HUP mDNSResponder

echo "Hosts file replaced, exiting."
exit
